@@ -5,14 +5,13 @@ use utf8;
 
 
 sub encode{
+	my $word=$_[0];
 
-	my $word=shift;
-
-	# let's take away the FIRST hamza ON/UNDER the alef from the word
+	#let's take away the FIRST hamza ON/UNDER the alef from the word
 	$word=~s/\x{0623}//; #HAMZA ON ALEF
 	$word=~s/\x{0625}//; #HAMZA UNDER ALEF
 
-	# let's take away the double-letters (=letter+shadda)
+	#let's take away the double-letters (=letter+shadda)
 	$word=~s/\x{0628}\x{0651}/bb/g;
 	$word=~s/\x{062A}\x{0651}/tt/g;
 	$word=~s/\x{062B}\x{0651}/_t_t/g;
@@ -41,7 +40,6 @@ sub encode{
 	$word=~s/\x{064A}\x{0651}/yy/g;
 	$word=~s/\x{0631}\x{0651}/rr/g;
 
-    # now let's think of single letters
 	$word=~s/\x{0627}/A/g; #ALEF;
 	$word=~s/\x{062A}/t/g; #TEH;
 	$word=~s/\x{0643}/k/g; #KAF
@@ -112,22 +110,22 @@ __END__
 
 =head1 NAME
 
-Lingua::AR::Word::Encode - Perl extension to encode Arabic words into ArabTeX
+Lingua::AR::Word::Encode - Perl extension for encoding Arabic words into ArabTeX
 
 =head1 SYNOPSIS
 
-	use Lingua::AR::Word::Encode;
+  use Lingua::AR::Word::Encoding;
 
-	$arabtex_form=Lingua::AR::Word::encode("ARABIC_WORD_IN_UTF8");
+$translitteration=Lingua::AR::Word::encode(ARABIC_WORD_IN_UTF8);
 
 =head1 DESCRIPTION
 
-This module will take care of encoding an Arabic word into ArabTeX, so that Arabic letters will be converted into English alphabet ones. This way we can interoperate with the ASCII-shell without requiring special Unicode-representation modules.
+This module will take care of encoding an Arabic word into ArabTeX, so that Arabic letters will be converted into English alphabet ones. This way we can interoperate with the ASCII-shell without any problems at all.
 
 
 =head1 SEE ALSO
 
-You may find more info about ArabTeX encoding at ftp://ftp.informatik.uni-stuttgart.de/pub/arabtex/arabtex.htm
+I've used ArabTeX "encoding" for local DB files, so that the shell won't argue with the filenames. You may find more info about that at ftp://ftp.informatik.uni-stuttgart.de/pub/arabtex/arabtex.htm
 
 
 
@@ -137,7 +135,7 @@ Andrea Benazzo, E<lt>andy@slacky.itE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2006 Andrea Benazzo. All rights reserved.
+Copyright (c) 2005 Andrea Benazzo. All rights reserved.
  This program is free software; you can redistribute it and/or
  modify it under the same terms as Perl itself.
 
